==> enterprisemodules-ora_config-2.5.0.tar.gz: enterprisemodules-ora_config-2.5.0/lib/puppet/type/ora_scheduler_job/job_action.rb <==
require 'pathname'

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:job_action) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access

  desc <<-EOD
    Specifies what the job is supposed to do.
    Depending on the job_type a PLSQL_BLOCK, STORED_PROCEDURE or FILENAME can be specified.

    Here is an example on how to use this:

        ora_scheduler_job{ 'me.my_job@sid':
          ...
          job_action => 'begin insert into session_tab select count(9) from v$session; end;',
          ...
        }

        or

        ora_scheduler_job{ 'me.my_job@sid':
          ...
          job_action => '/tmp/my_job.sql',
          ...
        }

    Puppet doesn't provide a default value.

  EOD

  to_translate_to_resource do |raw_resource|
    # TODO:
    # extend Puppet_X::EnterpriseModules::Oracle::Access
    # raw_res = raw_resource.column_data('JOB_ACTION')
    # hex_to_raw(raw_res)
    'content-in-database'
  end

  #
  # Here we have the content and do the compare.
  #
  def insync?(_is)
    if current_content == required_content
      true
    else
      current_content_file = Tempfile.new('ora_scheduler_job')
      current_content_file.write(current_content)
      current_content_file.close
      required_content_file = Tempfile.new('ora_scheduler_job')
      required_content_file.write(required_content)
      required_content_file.close
      file_diff = `diff #{current_content_file.path} #{required_content_file.path}`
      Puppet.info "#{path}: Difference is:\n#{file_diff}"
      false
    end
  end

  def change_to_s(currentvalue, _newvalue)
    if currentvalue == :absent
      'created job_action for job'
    else
      'changed job_action for job'
    end
  end

  on_modify do
    job_action_content = get_content
    statement = template('ora_config/ora_scheduler_job/modify_code_attribute.sql.erb', binding)
    sql statement, {:sid => resource.sid}
  end

  def get_content
    if Pathname(value).absolute?
      if File.file?(value)
        File.read(value)
      else
        fail "Unable to find file #{value} for job_action content"
      end
    else
      value
    end
  end

  def current_content
    return @current_content if @current_content
    job_action_code = sql(template('ora_config/ora_scheduler_job/job_action.sql.erb', binding), :sid => resource.sid)
    @current_content = process_content(job_action_code.collect { |l| hex_to_raw(l['CONTENT']) }.join)
  end

  def required_content
    @required_content ||= process_content(get_content)
  end

  def process_content(content)
    content.gsub(/CONTENT\s*\n-*\s*\n/, '') \
           .gsub(/--.*\n/, '') \
           .gsub(%r{^/\s*$}, '') \
           .gsub(/\s|\s|"|'/, '') \
           .delete("\n").upcase
  end

end

==> enterprisemodules-ora_config-3.8.1.tar.gz: enterprisemodules-ora_config-3.8.1/lib/puppet/type/ora_scheduler_job/job_action.rb <==
require 'pathname'

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:job_action) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access

  desc <<-EOD
    Specifies what the job is supposed to do.
    Depending on the job_type a PLSQL_BLOCK, STORED_PROCEDURE or FILENAME can be specified.

    Here is an example on how to use this:

        ora_scheduler_job{ 'me.my_job@sid':
          ...
          job_action => 'begin insert into session_tab select count(9) from v$session; end;',
          ...
        }

        or

        ora_scheduler_job{ 'me.my_job@sid':
          ...
          job_action => '/tmp/my_job.sql',
          ...
        }

    Puppet doesn't provide a default value.

  EOD

  to_translate_to_resource do |raw_resource|
    # TODO:
    # extend Puppet_X::EnterpriseModules::Oracle::Access
    # raw_res = raw_resource.column_data('JOB_ACTION')
    # hex_to_raw(raw_res)
    'content-in-database'
  end

  #
  # Here we have the content and do the compare.
  #
  def insync?(_is)
    if current_content == required_content
      true
    else
      current_content_file = Tempfile.new('ora_scheduler_job')
      current_content_file.write(current_content)
      current_content_file.close
      required_content_file = Tempfile.new('ora_scheduler_job')
      required_content_file.write(required_content)
      required_content_file.close
      file_diff = `diff #{current_content_file.path} #{required_content_file.path}`
      Puppet.info "#{path}: Difference is:\n#{file_diff}"
      false
    end
  end

  def change_to_s(currentvalue, _newvalue)
    if currentvalue.to_s == 'absent'
      'created job_action for job'
    else
      'changed job_action for job'
    end
  end

  on_modify do
    job_action_content = get_content
    statement = template('ora_config/ora_scheduler_job/modify_code_attribute.sql.erb', binding)
    sql statement, {:sid => resource.sid}
  end

  def get_content
    if Pathname(value).absolute?
      if File.file?(value)
        File.read(value)
      else
        fail "Unable to find file #{value} for job_action content"
      end
    else
      value
    end
  end

  def current_content
    return @current_content if @current_content
    job_action_code = sql(template('ora_config/ora_scheduler_job/job_action.sql.erb', binding), :sid => resource.sid)
    @current_content = process_content(job_action_code.collect { |l| hex_to_raw(l['CONTENT']) }.join)
  end

  def required_content
    @required_content ||= process_content(get_content)
  end

  def process_content(content)
    content.gsub(/CONTENT\s*\n-*\s*\n/, '') \
           .gsub(/--.*\n/, '') \
           .gsub(%r{^/\s*$}, '') \
           .gsub(/\s|\s|"|'/, '') \
           .delete("\n").upcase
  end

end
